==> apache-tomcat-8.5.92-src.tar.gz: apache-tomcat-8.5.92-src/java/javax/xml/ws/WebServiceRef.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package javax.xml.ws;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

@Target({ ElementType.TYPE, ElementType.METHOD, ElementType.FIELD })
@Retention(RetentionPolicy.RUNTIME)

public @interface WebServiceRef {
    String name() default "";

    @SuppressWarnings("rawtypes") // Can't use Class<?> because API needs to match specification
    Class type() default java.lang.Object.class;

    @SuppressWarnings("rawtypes") // Can't use Class<?> because API needs to match specification
    Class value() default java.lang.Object.class;

    String wsdlLocation() default "";

    String mappedName() default "";
}

==> apache-tomcat-9.0.63-src.tar.gz: apache-tomcat-9.0.63-src/java/javax/xml/ws/WebServiceRef.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package javax.xml.ws;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

@Target({ElementType.TYPE, ElementType.METHOD, ElementType.FIELD})
@Retention(RetentionPolicy.RUNTIME)

public @interface WebServiceRef {
    public String name() default "";
    @SuppressWarnings("rawtypes") // Can't use Class<?> because API needs to match specification
    public Class type() default java.lang.Object.class;
    @SuppressWarnings("rawtypes") // Can't use Class<?> because API needs to match specification
    public Class value() default java.lang.Object.class;
    public String wsdlLocation() default "";
    public String mappedName() default "";
}
